@@ -2,7 +2,7 @@ __title__ = 'Amino.fix-async'
 __author__ = 'Minori'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2021-2022 Minori'
-__version__ = '1.0.0'
+__version__ = '2.0.0'
 
 from .acm import ACM
 from .client import Client
@@ -12,7 +12,9 @@ from .lib.util import device, exceptions, headers, helpers, objects
 from requests import get
 from json import loads
 
-__newest__ = loads(get("https://pypi.python.org/pypi/amino.fix-async/json").text)["info"]["version"]
+__newest__ = loads(get("https://pypi.org/pypi/amino.fix-async/json").text)["info"]["version"]
 
 if __version__ != __newest__:
-    print(exceptions.LibraryUpdateAvailable(f"New version of {__title__} available: {__newest__} (Using {__version__})"))
+    print(f"New version of {__title__} available: {__newest__} (Using {__version__})")
+    print(f"To update to the latest version, write to pip this command - pip install --upgrade amino.fix-async")
+    print("Discord link - https://discord.gg/Bf3dpBRJHj")
